#include "swuser_config.h"
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/wait.h>
#include "taru.h"
#include "swparser_global.h"
#include "swevents_array.h"
#include "swcommon_options.h"

int 
main  {

  return 0;

}









